@@ -2,7 +2,7 @@
 # These tools are specificly to aid instructors in setting
 # up notebook templates with embedded instructions and tools
 # for students.
-# J. Gutow <jgutow@new.rr.com> January 30, 2020
+# J. Gutow <jgutow@new.rr.com> January 2021
 # license GPL V3 or greater.
 
 from IPython.display import HTML
@@ -11,7 +11,7 @@ from IPython.display import Javascript as JS
 import os
 # Instructor tools menu
 from input_table import * #import the input table builder
-from JPSLUtils import * # import the Utilities
+import JPSLUtils # import the Utilities
 # Locate JupyterPiDAQ package directory
 mydir = os.path.dirname(__file__)  # absolute path to directory containing this file.
 
@@ -25,7 +25,7 @@ def instmenu_act():
     tempscript += tempJSfile.read() + '</script>'
     tempJSfile.close()
     display(HTML(tempscript))
-    OTJS('createInstructorToolsMenu()')
+    JPSLUtils.OTJS('createInstructorToolsMenu()')
     warnstr = "This cell should only contain `import InstructorTools`"
     warnstr += " as it will be deleted when the tools"
     warnstr+= " are deactivated.\n\nWARNING: if you select the '!deactivate "
@@ -49,4 +49,5 @@ def instmenu_deact():
     print("Delete this cell after the menu has been removed.")
     pass
 
+JPSLUtils.JPSL_Tools_Menu()
 instmenu_act()
\ No newline at end of file
